@@ -9,27 +9,25 @@ pub struct InstantiateMsg {
     pub token: String,
     pub pair: String,
     pub lp_token: String,
+    pub distribution_schedule: Vec<(u64, u64, Uint128)>,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
 pub enum ExecuteMsg {
     Receive(Cw20ReceiveMsg),
-
     Unbond {
         amount: Uint128,
     },
-
+    /// Withdraw pending rewards
     Withdraw {},
-
     AutoStake {
-        amount: Uint128,
+        token_amount: Uint128,
         slippage_tolerance: Option<Decimal>,
     },
-
     AutoStakeHook {
         staker_addr: String,
-        prev_staking_token_amount: Uint128,
+        already_staked_amount: Uint128,
     },
 }
 
@@ -37,7 +35,6 @@ pub enum ExecuteMsg {
 #[serde(rename_all = "snake_case")]
 pub enum Cw20HookMsg {
     Bond {},
-    DepositReward { },
 }
 
 /// We currently take no arguments for migrations
